using System;
using System.Collections.Generic;
using System.Text;
using Monty = montylingua;

namespace CPIDR
{
  /// <summary>
  /// This class provides the interface for the tagger, 
  /// in our case MontyLingua, but others could be substituted
  /// by modifying only this class.
  /// Much of the power of MontyLingua is not used here because
  /// we want to substitute other taggers later.
  /// </summary>
  static class Tagger
  {

    static Monty.JMontyLingua theMonty;

    /// <summary>
    /// Boolean variable indicating whether tagger has been initialized.
    /// </summary>
    public static bool Initialized = false;

    /// <summary>
    /// Must be called before using the tagger.
    /// </summary>
    public static void Initialize()
    {
      try
      {
        theMonty = new Monty.JMontyLingua();
        Initialized = true;
      }
      catch (Exception e)
      {
        throw new Exception("CPIDR: Cannot start MontyLingua.  MDF files may be missing from .exe folder.",e);
      }
    }

    /// <summary>
    /// Takes a text (in a long string) and returns it tagged.
    /// </summary>
    public static string TagText(string text)
    {
      if (theMonty == null)
      {
        throw new Exception("CPDIR: Tagger must be initialized before it can be used.");
      }

      string r;
      try
      {
        r = theMonty.tag_text(text);
      }
      catch (Exception e)
      {
        throw new Exception("Problem tagging text with MontyLingua.", e);
      }

      // MontyLingua outputs ' ' after most tags but '\n\n' after the end of a sentence.
      // Since we don't want to rely on this, we turn it back into a space.

      return r.Replace("\n\n", " "); 
    }
  }
}
